@@ -23,6 +23,10 @@
 
 #ifdef SDL_VIDEO_DRIVER_X11
 
+#ifdef __CYGWIN__
+#undef SDL_VIDEO_DRIVER_WINDOWS
+#endif
+
 #include "SDL_x11video.h"
 #include "SDL_hints.h"
 
